from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationRawEnumField(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    APPLICATION_RAW_ENUM_FIELD_UNSPECIFIED: _ClassVar[ApplicationRawEnumField]
    APPLICATION_RAW_ENUM_FIELD_NAME: _ClassVar[ApplicationRawEnumField]
    APPLICATION_RAW_ENUM_FIELD_VERSION: _ClassVar[ApplicationRawEnumField]
    APPLICATION_RAW_ENUM_FIELD_NAMESPACE: _ClassVar[ApplicationRawEnumField]
    APPLICATION_RAW_ENUM_FIELD_SERVICE: _ClassVar[ApplicationRawEnumField]
APPLICATION_RAW_ENUM_FIELD_UNSPECIFIED: ApplicationRawEnumField
APPLICATION_RAW_ENUM_FIELD_NAME: ApplicationRawEnumField
APPLICATION_RAW_ENUM_FIELD_VERSION: ApplicationRawEnumField
APPLICATION_RAW_ENUM_FIELD_NAMESPACE: ApplicationRawEnumField
APPLICATION_RAW_ENUM_FIELD_SERVICE: ApplicationRawEnumField

class ApplicationRawField(_message.Message):
    __slots__ = ["field"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    field: ApplicationRawEnumField
    def __init__(self, field: _Optional[_Union[ApplicationRawEnumField, str]] = ...) -> None: ...

class ApplicationField(_message.Message):
    __slots__ = ["application_field"]
    APPLICATION_FIELD_FIELD_NUMBER: _ClassVar[int]
    application_field: ApplicationRawField
    def __init__(self, application_field: _Optional[_Union[ApplicationRawField, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: versions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15versions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.versions\"\x15\n\x13ListVersionsRequest\"1\n\x14ListVersionsResponse\x12\x0c\n\x04\x63ore\x18\x01 \x01(\t\x12\x0b\n\x03\x61pi\x18\x02 \x01(\tB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Versionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'versions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Versions'
  _globals['_LISTVERSIONSREQUEST']._serialized_start=55
  _globals['_LISTVERSIONSREQUEST']._serialized_end=76
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=78
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=127
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: submitter_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import objects_pb2 as objects__pb2
from ..common import submitter_common_pb2 as submitter__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17submitter_service.proto\x12\x1d\x61rmonik.api.grpc.v1.submitter\x1a\robjects.proto\x1a\x16submitter_common.proto2\xe0\r\n\tSubmitter\x12^\n\x17GetServiceConfiguration\x12\x1a.armonik.api.grpc.v1.Empty\x1a\".armonik.api.grpc.v1.Configuration\"\x03\x88\x02\x01\x12|\n\rCreateSession\x12\x33.armonik.api.grpc.v1.submitter.CreateSessionRequest\x1a\x31.armonik.api.grpc.v1.submitter.CreateSessionReply\"\x03\x88\x02\x01\x12N\n\rCancelSession\x12\x1c.armonik.api.grpc.v1.Session\x1a\x1a.armonik.api.grpc.v1.Empty\"\x03\x88\x02\x01\x12~\n\x10\x43reateSmallTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateSmallTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply\"\x03\x88\x02\x01\x12\x80\x01\n\x10\x43reateLargeTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateLargeTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply\"\x03\x88\x02\x01(\x01\x12\\\n\tListTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1f.armonik.api.grpc.v1.TaskIdList\"\x03\x88\x02\x01\x12o\n\x0cListSessions\x12,.armonik.api.grpc.v1.submitter.SessionFilter\x1a,.armonik.api.grpc.v1.submitter.SessionIdList\"\x03\x88\x02\x01\x12X\n\nCountTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Count\"\x03\x88\x02\x01\x12k\n\x12TryGetResultStream\x12\".armonik.api.grpc.v1.ResultRequest\x1a*.armonik.api.grpc.v1.submitter.ResultReply\"\x03\x88\x02\x01\x30\x01\x12\\\n\x10TryGetTaskOutput\x12&.armonik.api.grpc.v1.TaskOutputRequest\x1a\x1b.armonik.api.grpc.v1.Output\"\x03\x88\x02\x01\x12p\n\x13WaitForAvailability\x12\".armonik.api.grpc.v1.ResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.AvailabilityReply\"\x03\x88\x02\x01\x12`\n\x11WaitForCompletion\x12*.armonik.api.grpc.v1.submitter.WaitRequest\x1a\x1a.armonik.api.grpc.v1.Count\"\x03\x88\x02\x01\x12Y\n\x0b\x43\x61ncelTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Empty\"\x03\x88\x02\x01\x12|\n\rGetTaskStatus\x12\x33.armonik.api.grpc.v1.submitter.GetTaskStatusRequest\x1a\x31.armonik.api.grpc.v1.submitter.GetTaskStatusReply\"\x03\x88\x02\x01\x12\x82\x01\n\x0fGetResultStatus\x12\x35.armonik.api.grpc.v1.submitter.GetResultStatusRequest\x1a\x33.armonik.api.grpc.v1.submitter.GetResultStatusReply\"\x03\x88\x02\x01\x12|\n\x0cWatchResults\x12\x31.armonik.api.grpc.v1.submitter.WatchResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.WatchResultStream\"\x03\x88\x02\x01(\x01\x30\x01\x42 \xaa\x02\x1d\x41rmoniK.Api.gRPC.V1.Submitterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'submitter_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\035ArmoniK.Api.gRPC.V1.Submitter'
  _SUBMITTER.methods_by_name['GetServiceConfiguration']._options = None
  _SUBMITTER.methods_by_name['GetServiceConfiguration']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateSession']._options = None
  _SUBMITTER.methods_by_name['CreateSession']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CancelSession']._options = None
  _SUBMITTER.methods_by_name['CancelSession']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateSmallTasks']._options = None
  _SUBMITTER.methods_by_name['CreateSmallTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateLargeTasks']._options = None
  _SUBMITTER.methods_by_name['CreateLargeTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['ListTasks']._options = None
  _SUBMITTER.methods_by_name['ListTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['ListSessions']._options = None
  _SUBMITTER.methods_by_name['ListSessions']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CountTasks']._options = None
  _SUBMITTER.methods_by_name['CountTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['TryGetResultStream']._options = None
  _SUBMITTER.methods_by_name['TryGetResultStream']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['TryGetTaskOutput']._options = None
  _SUBMITTER.methods_by_name['TryGetTaskOutput']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WaitForAvailability']._options = None
  _SUBMITTER.methods_by_name['WaitForAvailability']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WaitForCompletion']._options = None
  _SUBMITTER.methods_by_name['WaitForCompletion']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CancelTasks']._options = None
  _SUBMITTER.methods_by_name['CancelTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['GetTaskStatus']._options = None
  _SUBMITTER.methods_by_name['GetTaskStatus']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['GetResultStatus']._options = None
  _SUBMITTER.methods_by_name['GetResultStatus']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WatchResults']._options = None
  _SUBMITTER.methods_by_name['WatchResults']._serialized_options = b'\210\002\001'
  _globals['_SUBMITTER']._serialized_start=98
  _globals['_SUBMITTER']._serialized_end=1858
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import objects_pb2 as objects__pb2
from ..common import results_common_pb2 as results__common__pb2


class ResultsStub(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListResults = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/ListResults',
                request_serializer=results__common__pb2.ListResultsRequest.SerializeToString,
                response_deserializer=results__common__pb2.ListResultsResponse.FromString,
                )
        self.GetResult = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/GetResult',
                request_serializer=results__common__pb2.GetResultRequest.SerializeToString,
                response_deserializer=results__common__pb2.GetResultResponse.FromString,
                )
        self.GetOwnerTaskId = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/GetOwnerTaskId',
                request_serializer=results__common__pb2.GetOwnerTaskIdRequest.SerializeToString,
                response_deserializer=results__common__pb2.GetOwnerTaskIdResponse.FromString,
                )
        self.CreateResultsMetaData = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/CreateResultsMetaData',
                request_serializer=results__common__pb2.CreateResultsMetaDataRequest.SerializeToString,
                response_deserializer=results__common__pb2.CreateResultsMetaDataResponse.FromString,
                )
        self.CreateResults = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/CreateResults',
                request_serializer=results__common__pb2.CreateResultsRequest.SerializeToString,
                response_deserializer=results__common__pb2.CreateResultsResponse.FromString,
                )
        self.UploadResultData = channel.stream_unary(
                '/armonik.api.grpc.v1.results.Results/UploadResultData',
                request_serializer=results__common__pb2.UploadResultDataRequest.SerializeToString,
                response_deserializer=results__common__pb2.UploadResultDataResponse.FromString,
                )
        self.DownloadResultData = channel.unary_stream(
                '/armonik.api.grpc.v1.results.Results/DownloadResultData',
                request_serializer=results__common__pb2.DownloadResultDataRequest.SerializeToString,
                response_deserializer=results__common__pb2.DownloadResultDataResponse.FromString,
                )
        self.DeleteResultsData = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/DeleteResultsData',
                request_serializer=results__common__pb2.DeleteResultsDataRequest.SerializeToString,
                response_deserializer=results__common__pb2.DeleteResultsDataResponse.FromString,
                )
        self.GetServiceConfiguration = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/GetServiceConfiguration',
                request_serializer=objects__pb2.Empty.SerializeToString,
                response_deserializer=results__common__pb2.ResultsServiceConfigurationResponse.FromString,
                )
        self.WatchResults = channel.stream_stream(
                '/armonik.api.grpc.v1.results.Results/WatchResults',
                request_serializer=results__common__pb2.WatchResultRequest.SerializeToString,
                response_deserializer=results__common__pb2.WatchResultResponse.FromString,
                )


class ResultsServicer(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    def ListResults(self, request, context):
        """*
        Get a results list using pagination, filters and sorting
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResult(self, request, context):
        """*
        Get a result by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOwnerTaskId(self, request, context):
        """*
        Get the id of the task that should produce the result
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResultsMetaData(self, request, context):
        """*
        Create the metadata of multiple results at once
        Data have to be uploaded separately
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResults(self, request, context):
        """*
        Create one result with data included in the request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadResultData(self, request_iterator, context):
        """*
        Upload data for result with stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadResultData(self, request, context):
        """*
        Retrieve data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResultsData(self, request, context):
        """*
        Delete data from multiple results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceConfiguration(self, request, context):
        """*
        Get the configuration of the service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchResults(self, request_iterator, context):
        """*
        This endpoint allows a user to watch a list of results and be notified when there is any change.
        The user sends the list of ids they want to watch.
        The submitter will then send the statuses for all requested ids immediately and keep the stream open.
        Ids not present in DB will be returned at that time with the special state NOTFOUND.
        The submitter will send updates to the client via the opened stream.
        Any reply can be implicitely chunked if there are too many event to report at the same time (or for the first reply).
        It is possible to filter out specific statuses from events.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResultsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListResults': grpc.unary_unary_rpc_method_handler(
                    servicer.ListResults,
                    request_deserializer=results__common__pb2.ListResultsRequest.FromString,
                    response_serializer=results__common__pb2.ListResultsResponse.SerializeToString,
            ),
            'GetResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResult,
                    request_deserializer=results__common__pb2.GetResultRequest.FromString,
                    response_serializer=results__common__pb2.GetResultResponse.SerializeToString,
            ),
            'GetOwnerTaskId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOwnerTaskId,
                    request_deserializer=results__common__pb2.GetOwnerTaskIdRequest.FromString,
                    response_serializer=results__common__pb2.GetOwnerTaskIdResponse.SerializeToString,
            ),
            'CreateResultsMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResultsMetaData,
                    request_deserializer=results__common__pb2.CreateResultsMetaDataRequest.FromString,
                    response_serializer=results__common__pb2.CreateResultsMetaDataResponse.SerializeToString,
            ),
            'CreateResults': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResults,
                    request_deserializer=results__common__pb2.CreateResultsRequest.FromString,
                    response_serializer=results__common__pb2.CreateResultsResponse.SerializeToString,
            ),
            'UploadResultData': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadResultData,
                    request_deserializer=results__common__pb2.UploadResultDataRequest.FromString,
                    response_serializer=results__common__pb2.UploadResultDataResponse.SerializeToString,
            ),
            'DownloadResultData': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadResultData,
                    request_deserializer=results__common__pb2.DownloadResultDataRequest.FromString,
                    response_serializer=results__common__pb2.DownloadResultDataResponse.SerializeToString,
            ),
            'DeleteResultsData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResultsData,
                    request_deserializer=results__common__pb2.DeleteResultsDataRequest.FromString,
                    response_serializer=results__common__pb2.DeleteResultsDataResponse.SerializeToString,
            ),
            'GetServiceConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceConfiguration,
                    request_deserializer=objects__pb2.Empty.FromString,
                    response_serializer=results__common__pb2.ResultsServiceConfigurationResponse.SerializeToString,
            ),
            'WatchResults': grpc.stream_stream_rpc_method_handler(
                    servicer.WatchResults,
                    request_deserializer=results__common__pb2.WatchResultRequest.FromString,
                    response_serializer=results__common__pb2.WatchResultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.results.Results', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Results(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    @staticmethod
    def ListResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/ListResults',
            results__common__pb2.ListResultsRequest.SerializeToString,
            results__common__pb2.ListResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/GetResult',
            results__common__pb2.GetResultRequest.SerializeToString,
            results__common__pb2.GetResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOwnerTaskId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/GetOwnerTaskId',
            results__common__pb2.GetOwnerTaskIdRequest.SerializeToString,
            results__common__pb2.GetOwnerTaskIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResultsMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/CreateResultsMetaData',
            results__common__pb2.CreateResultsMetaDataRequest.SerializeToString,
            results__common__pb2.CreateResultsMetaDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/CreateResults',
            results__common__pb2.CreateResultsRequest.SerializeToString,
            results__common__pb2.CreateResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadResultData(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.results.Results/UploadResultData',
            results__common__pb2.UploadResultDataRequest.SerializeToString,
            results__common__pb2.UploadResultDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadResultData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/armonik.api.grpc.v1.results.Results/DownloadResultData',
            results__common__pb2.DownloadResultDataRequest.SerializeToString,
            results__common__pb2.DownloadResultDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteResultsData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/DeleteResultsData',
            results__common__pb2.DeleteResultsDataRequest.SerializeToString,
            results__common__pb2.DeleteResultsDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/GetServiceConfiguration',
            objects__pb2.Empty.SerializeToString,
            results__common__pb2.ResultsServiceConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchResults(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/armonik.api.grpc.v1.results.Results/WatchResults',
            results__common__pb2.WatchResultRequest.SerializeToString,
            results__common__pb2.WatchResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
